Test coverage report: markupmirror.exceptions

# markupmirror.exceptions: 2 total statements, 100.0% covered

Generated: Wed 2012-04-11 05:19 CDT

Source file: /home/buechler/Sites/django-markupmirror/markupmirror/exceptions.py

Stats: 2 executed, 0 missed, 0 excluded, 4 ignored

1. `class MarkupError(Exception):`
2. `"""General execution error for markups."""`
3. ``
4. ``
5. `class InvalidMarkup(Exception):`
6. `"""Raised when a markup is not subclassing BaseMarkup."""`